@@ -10,7 +10,7 @@ from cachetools import TTLCache
 
 class SmappeeServiceLocation(object):
 
-    def __init__(self, service_location_id, service_location_uuid, name, device_serial_number, smappee_api):
+    def __init__(self, service_location_id, service_location_uuid, name, device_serial_number, smappee_api, farm):
         # service location details
         self._service_location_id = service_location_id
         self._service_location_uuid = service_location_uuid
@@ -22,6 +22,7 @@ class SmappeeServiceLocation(object):
 
         # api instance to (re)load consumption data
         self.smappee_api = smappee_api
+        self._farm = farm
 
         # mqtt connections
         self.mqtt_connection_central = None
@@ -92,10 +93,11 @@ class SmappeeServiceLocation(object):
 
         # Load appliances
         for appliance in sl_metering_configuration.get('appliances'):
-            self._add_appliance(id=appliance.get('id'),
-                                name=appliance.get('name'),
-                                type=appliance.get('type'),
-                                source_type=appliance.get('sourceType'))
+            if appliance.get('type') != 'Find me' and appliance.get('sourceType') == 'NILM':
+                self._add_appliance(id=appliance.get('id'),
+                                    name=appliance.get('name'),
+                                    type=appliance.get('type'),
+                                    source_type=appliance.get('sourceType'))
 
         # Load actuators (Smappee Switches, Comfort Plugs, IO modules)
         for actuator in sl_metering_configuration.get('actuators'):
@@ -103,6 +105,7 @@ class SmappeeServiceLocation(object):
                                name=actuator.get('name'),
                                serialnumber=actuator.get('serialNumber') if 'serialNumber' in actuator else None,
                                state_values=actuator.get('states'),
+                               connection_state=actuator.get('connectionState'),
                                actuator_type=actuator.get('type'))
 
         # Load sensors (Smappee Gas and Water)
@@ -258,25 +261,24 @@ class SmappeeServiceLocation(object):
     def actuators(self):
         return self._actuators
 
-    def _add_actuator(self, id, name, serialnumber, state_values, actuator_type):
-        type_mapping = {
-            'CCD_CHACON_SIMPLE': 'PLUG',
-            'CCD_ELRO_SIMPLE': 'PLUG',
-            'CCD_HE_ADVANCED': 'PLUG',
-            'CCD_LEAF_LITE': 'SWITCH',
-            'INFINITY_OUTPUT_MODULE': 'OUTPUT_MODULE',
-        }
+    def _add_actuator(self, id, name, serialnumber, state_values, connection_state, actuator_type):
         self.actuators[id] = SmappeeActuator(id=id,
                                              name=name,
                                              serialnumber=serialnumber,
                                              state_values=state_values,
-                                             type=type_mapping.get(actuator_type))
+                                             connection_state=connection_state,
+                                             type=actuator_type)
 
         # Get actuator state
         state = self.smappee_api.get_actuator_state(service_location_id=self.service_location_id,
                                                     actuator_id=id)
         self.actuators.get(id).state = state
 
+        # Get actuator connection state
+        connection_state = self.smappee_api.get_actuator_connection_state(service_location_id=self.service_location_id,
+                                                                          actuator_id=id)
+        self.actuators.get(id).connection_state = connection_state
+
     def set_actuator_state(self, id, state, since=None, api=True):
         if id in self.actuators:
             if api:
@@ -402,7 +404,8 @@ class SmappeeServiceLocation(object):
 
     def load_mqtt_connection(self, kind):
         mqtt_connection = SmappeeMqtt(service_location=self,
-                                      kind=kind)
+                                      kind=kind,
+                                      farm=self._farm)
         mqtt_connection.start()
         return mqtt_connection
 
